@@ -465,11 +465,10 @@ def _save_chunk(context, chunk, content_bytes, path, type, mimetype):
 @gen.coroutine
 def _save_bytes(context, content_bytes, path, type, mimetype):
     object_name = _key(context, path)
-    _put_object(context, context.s3_bucket, content_bytes, object_name)
+    response = _put_object(context, context.s3_bucket, content_bytes, object_name)
 
-    last_modified_str = response.headers['Date']
-    last_modified = datetime.datetime.strptime(
-        last_modified_str, "%a, %d %b %Y %H:%M:%S GMT")
+    # last_modified_str = response.headers['Date']
+    last_modified = f"{datetime.datetime.now():%a, %d %b %Y %H:%M:%S GMT}"
     return _saved_model(path, type, mimetype, last_modified)
 
 
